@@ -4,7 +4,8 @@ use web_audio_api::media::{MediaElement, OggVorbisDecoder};
 use web_audio_api::node::{AudioControllableSourceNode, AudioNode, AudioScheduledSourceNode};
 
 fn main() {
-    let context = AudioContext::new();
+    env_logger::init();
+    let context = AudioContext::new(None);
 
     // setup background music:
     // read from local file
