@@ -3,7 +3,8 @@ use web_audio_api::node::AudioNode;
 use web_audio_api::node::AudioScheduledSourceNode;
 
 fn main() {
-    let context = AudioContext::new();
+    env_logger::init();
+    let context = AudioContext::new(None);
 
     // Create a friendly tone
     let tone = context.create_oscillator();
