@@ -9,7 +9,7 @@
 
 use std::ops::Range;
 use std::sync::atomic::{AtomicU64, Ordering};
-use std::sync::Arc;
+use std::sync::{Arc, Mutex};
 
 // magic node values
 /// Destination node id is always at index 0
@@ -19,19 +19,19 @@ const LISTENER_NODE_ID: u64 = 1;
 /// listener audio parameters ids are always at index 2 through 12
 const LISTENER_PARAM_IDS: Range<u64> = 2..12;
 
-use crate::buffer::{AudioBuffer, ChannelConfigOptions, ChannelCountMode, ChannelInterpretation};
-use crate::graph::{NodeIndex, RenderThread};
+use crate::buffer::{AudioBuffer, AudioBufferOptions, ChannelData};
 use crate::media::{MediaElement, MediaStream};
 use crate::message::ControlMessage;
 use crate::node::{
-    self, AnalyserOptions, AudioBufferSourceNodeOptions, AudioNode, ChannelMergerOptions,
-    ChannelSplitterOptions, ConstantSourceOptions, DelayOptions, GainOptions, IirFilterOptions,
-    PannerOptions, PeriodicWave, PeriodicWaveOptions,
+    self, AnalyserOptions, AudioBufferSourceOptions, AudioNode, ChannelConfigOptions,
+    ChannelCountMode, ChannelInterpretation, ChannelMergerOptions, ChannelSplitterOptions,
+    ConstantSourceOptions, DelayOptions, GainOptions, IirFilterOptions, PannerOptions,
+    PeriodicWave, PeriodicWaveOptions,
 };
 use crate::param::{AudioParam, AudioParamEvent, AudioParamOptions};
-use crate::process::AudioProcessor;
+use crate::render::{AudioProcessor, NodeIndex, RenderThread};
 use crate::spatial::{AudioListener, AudioListenerParams};
-use crate::{SampleRate, BUFFER_SIZE};
+use crate::{SampleRate, RENDER_QUANTUM_SIZE};
 
 #[cfg(not(test))]
 use crate::io;
@@ -68,6 +68,8 @@ struct BaseAudioContextInner {
     node_id_inc: AtomicU64,
     /// message channel from control to render thread
     render_channel: Sender<ControlMessage>,
+    /// control messages that cannot be sent immediately
+    queued_messages: Mutex<Vec<ControlMessage>>,
     /// number of frames played
     frames_played: Arc<AtomicU64>,
     /// AudioListener fields
@@ -80,6 +82,104 @@ pub trait AsBaseAudioContext {
     /// retrieves the `BaseAudioContext` associated with the concrete `AudioContext`
     fn base(&self) -> &BaseAudioContext;
 
+    /// Retrieves an [`AudioBuffer`] from a given [`std::fs::File`]
+    ///
+    /// *Warning:* in the current implementation `decode_audio_data` only accepts
+    /// `.wav` files and do not perform any resampling operation. Be carefull
+    /// to use audio files that match the current sample rate or the file will
+    /// pitched when played.
+    fn decode_audio_data(&self, file: std::fs::File) -> AudioBuffer {
+        // @see - https://github.com/orottier/web-audio-api-rs/issues/42
+        // @note - should also be async, but that's not a big deal neither for now
+        let buf_reader = std::io::BufReader::new(file);
+        let mut reader = hound::WavReader::new(buf_reader).unwrap();
+        let hound::WavSpec {
+            channels,
+            sample_rate: _, // @todo - use for resampling
+            bits_per_sample,
+            sample_format,
+        } = reader.spec();
+
+        let number_of_channels = channels as usize;
+        let length = reader.duration() as usize;
+
+        let mut decoded: Vec<Vec<f32>> = Vec::with_capacity(number_of_channels);
+
+        for _ in 0..number_of_channels {
+            decoded.push(Vec::<f32>::with_capacity(length));
+        }
+
+        // @note - hound retrieves interleaved values
+        // cf. https://docs.rs/hound/latest/hound/struct.WavReader.html#method.samples
+        match sample_format {
+            hound::SampleFormat::Int => {
+                let mut channel_number = 0;
+
+                if bits_per_sample == 16 {
+                    for sample in reader.samples::<i16>() {
+                        let s = f32::from(sample.unwrap()) / f32::from(i16::MAX);
+                        assert!(s.abs() <= 1.);
+                        decoded[channel_number].push(s);
+                        // next sample belongs to the next channel
+                        channel_number = (channel_number + 1) % number_of_channels;
+                    }
+                } else {
+                    panic!("bits_per_sample {:?} not implemented", bits_per_sample);
+                }
+            }
+            hound::SampleFormat::Float => {
+                // this one is not tested
+                let mut channel_number = 0;
+
+                for sample in reader.samples::<f32>() {
+                    let s = sample.unwrap();
+                    decoded[channel_number].push(s);
+                    // next sample belongs to the next channel
+                    channel_number = (channel_number + 1) % number_of_channels;
+                }
+            }
+        }
+
+        assert_eq!(decoded[0].len(), length);
+
+        // [spec] Take the result, representing the decoded linear PCM audio data,
+        // and resample it to the sample-rate of the BaseAudioContext if it is
+        // different from the sample-rate of audioData.
+
+        // @todo - resample if needed
+        // if (sample_rate != self.sample_rate()) {}
+
+        let mut channels = Vec::<ChannelData>::with_capacity(number_of_channels);
+
+        // replace raw decoded channels with `DataChannel`
+        for raw_channel in decoded {
+            let channel = ChannelData::from(raw_channel);
+            channels.push(channel);
+        }
+
+        AudioBuffer::from_channels(channels, self.sample_rate())
+    }
+
+    /// Create an new "in-memory" `AudioBuffer` with the given number of channels,
+    /// length (i.e. number of samples per channel) and sample rate.
+    ///
+    /// Note: In most cases you will want the sample rate to match the current
+    /// audio context sample rate.
+    fn create_buffer(
+        &self,
+        number_of_channels: usize,
+        length: usize,
+        sample_rate: SampleRate,
+    ) -> AudioBuffer {
+        let options = AudioBufferOptions {
+            number_of_channels,
+            length,
+            sample_rate,
+        };
+
+        AudioBuffer::new(options)
+    }
+
     /// Creates an `OscillatorNode`, a source representing a periodic waveform. It basically
     /// generates a tone.
     fn create_oscillator(&self) -> node::OscillatorNode {
@@ -195,7 +295,7 @@ pub trait AsBaseAudioContext {
     ///
     /// Note: do not forget to `start()` the node.
     fn create_buffer_source(&self) -> node::AudioBufferSourceNode {
-        node::AudioBufferSourceNode::new(self.base(), AudioBufferSourceNodeOptions::default())
+        node::AudioBufferSourceNode::new(self.base(), AudioBufferSourceOptions::default())
     }
 
     /// Creates a `PannerNode`
@@ -227,8 +327,8 @@ pub trait AsBaseAudioContext {
             (node, Box::new(proc))
         });
 
-        // audio params are connected to the 'hidden' u32::MAX input. TODO make nicer
-        self.base().connect(param.id(), dest, 0, u32::MAX);
+        // Connect the param to the node, once the node is registered inside the audio graph.
+        self.base().queue_audio_param_connect(&param, dest);
 
         let proc_id = AudioParamId(param.id().0);
         (param, proc_id)
@@ -506,6 +606,7 @@ impl BaseAudioContext {
             sample_rate,
             channels,
             render_channel,
+            queued_messages: Mutex::new(Vec::new()),
             node_id_inc: AtomicU64::new(0),
             frames_played,
             listener_params: None,
@@ -586,12 +687,7 @@ impl BaseAudioContext {
     /// Construct a new pair of [`node::AudioNode`] and [`AudioProcessor`]
     ///
     /// The `AudioNode` lives in the user-facing control thread. The Processor is sent to the render thread.
-    ///
-    /// # Panics
-    ///
-    /// Will panic if:
-    ///
-    /// * Message send to the render thread is not received in less than 10 ms
+    #[allow(clippy::missing_panics_doc)]
     pub fn register<
         T: node::AudioNode,
         F: FnOnce(AudioContextRegistration) -> (T, Box<dyn AudioProcessor>),
@@ -620,6 +716,18 @@ impl BaseAudioContext {
         };
         self.inner.render_channel.send(message).unwrap();
 
+        // resolve control messages that depend on this registration
+        let mut queued = self.inner.queued_messages.lock().unwrap();
+        let mut i = 0; // waiting for Vec::drain_filter to stabilize
+        while i < queued.len() {
+            if matches!(&queued[i], ControlMessage::ConnectNode {to, ..} if *to == id) {
+                let m = queued.remove(i);
+                self.inner.render_channel.send(m).unwrap();
+            } else {
+                i += 1;
+            }
+        }
+
         node
     }
 
@@ -634,6 +742,19 @@ impl BaseAudioContext {
         self.inner.render_channel.send(message).unwrap();
     }
 
+    /// Schedule a connection of an `AudioParam` to the `AudioNode` it belongs to
+    ///
+    /// It is not performed immediately as the `AudioNode` is not registered at this point.
+    fn queue_audio_param_connect(&self, param: &AudioParam, audio_node: &AudioNodeId) {
+        let message = ControlMessage::ConnectNode {
+            from: param.id().0,
+            to: audio_node.0,
+            output: 0,
+            input: u32::MAX, // audio params connect to the 'hidden' input port
+        };
+        self.inner.queued_messages.lock().unwrap().push(message);
+    }
+
     /// connects the `from` audio node to the `to` audio node
     pub(crate) fn disconnect(&self, from: &AudioNodeId, to: &AudioNodeId) {
         let message = ControlMessage::DisconnectNode {
@@ -723,9 +844,10 @@ impl OfflineAudioContext {
     /// `OfflineAudioContext` doesn't start rendering automatically
     /// You need to call this function to start the audio rendering
     pub fn start_rendering(&mut self) -> AudioBuffer {
-        // make buffer_size always a multiple of BUFFER_SIZE, so we can still render piecewise with
+        // make buffer_size always a multiple of RENDER_QUANTUM_SIZE, so we can still render piecewise with
         // the desired number of frames.
-        let buffer_size = (self.length + BUFFER_SIZE - 1) / BUFFER_SIZE * BUFFER_SIZE;
+        let buffer_size =
+            (self.length + RENDER_QUANTUM_SIZE - 1) / RENDER_QUANTUM_SIZE * RENDER_QUANTUM_SIZE;
 
         let mut buf = self.renderer.render_audiobuffer(buffer_size);
         let _split = buf.split_off(self.length);
@@ -756,4 +878,33 @@ mod tests {
         // Send Sync and 'static
         require_send_sync_static(registration);
     }
+
+    #[test]
+    fn test_decode_audio_data() {
+        // @todo - complete and assert when resampling will be implemented
+        let context = AudioContext::new(None);
+
+        let file = std::fs::File::open("sample.wav").unwrap();
+        let audio_buffer = context.decode_audio_data(file);
+
+        println!("----------------------------------------------");
+        println!(
+            "- number_of_channels: {:?}",
+            audio_buffer.number_of_channels()
+        );
+        println!("- length: {:?}", audio_buffer.length());
+        println!("- sample_rate: {:?}", audio_buffer.sample_rate());
+        println!("- duration: {:?}", audio_buffer.duration());
+
+        let left_start = &audio_buffer.get_channel_data(0)[0..100];
+        let right_start = &audio_buffer.get_channel_data(1)[0..100];
+
+        println!("----------------------------------------------");
+        println!("@todo - should check that resampling is ok    ");
+        println!("----------------------------------------------");
+        println!("- left_start: {:?}", left_start);
+        println!("----------------------------------------------");
+        println!("- right_start: {:?}", right_start);
+        println!("----------------------------------------------");
+    }
 }
