@@ -1,10 +1,10 @@
 use float_eq::assert_float_eq;
-use web_audio_api::buffer::{AudioBuffer, ChannelData};
+use web_audio_api::buffer::AudioBuffer;
 use web_audio_api::context::AsBaseAudioContext;
 use web_audio_api::context::OfflineAudioContext;
 use web_audio_api::media::MediaElement;
 use web_audio_api::node::{AudioControllableSourceNode, AudioNode, AudioScheduledSourceNode};
-use web_audio_api::{SampleRate, BUFFER_SIZE};
+use web_audio_api::{SampleRate, RENDER_QUANTUM_SIZE};
 
 use std::sync::atomic::{AtomicBool, Ordering};
 use std::sync::Arc;
@@ -33,8 +33,8 @@ impl Iterator for SlowMedia {
 
         self.value += 1.;
 
-        let channel_data = ChannelData::from(vec![self.value; BUFFER_SIZE]);
-        let buffer = AudioBuffer::from_channels(vec![channel_data], self.sample_rate);
+        let samples = vec![vec![self.value; RENDER_QUANTUM_SIZE]];
+        let buffer = AudioBuffer::from(samples, self.sample_rate);
 
         Some(Ok(buffer))
     }
@@ -42,7 +42,7 @@ impl Iterator for SlowMedia {
 
 #[test]
 fn test_media_buffering() {
-    let mut context = OfflineAudioContext::new(1, BUFFER_SIZE, SampleRate(44_100));
+    let mut context = OfflineAudioContext::new(1, RENDER_QUANTUM_SIZE, SampleRate(44_100));
 
     let block = Arc::new(AtomicBool::new(true));
     let finished = Arc::new(AtomicBool::new(false));
@@ -65,8 +65,8 @@ fn test_media_buffering() {
     // should be silent since the media stream did not yield any output
     let output = context.start_rendering();
     assert_float_eq!(
-        output.channel_data(0).as_slice(),
-        &[0.; BUFFER_SIZE][..],
+        output.get_channel_data(0),
+        &[0.; RENDER_QUANTUM_SIZE][..],
         abs_all <= 0.
     );
 
@@ -76,16 +76,16 @@ fn test_media_buffering() {
     // should contain output
     let output = context.start_rendering();
     assert_float_eq!(
-        output.channel_data(0).as_slice(),
-        &[2.; BUFFER_SIZE][..],
+        output.get_channel_data(0),
+        &[2.; RENDER_QUANTUM_SIZE][..],
         abs_all <= 0.
     );
 
     // should be silent since the media stream did not yield any output
     let output = context.start_rendering();
     assert_float_eq!(
-        output.channel_data(0).as_slice(),
-        &[0.; BUFFER_SIZE][..],
+        output.get_channel_data(0),
+        &[0.; RENDER_QUANTUM_SIZE][..],
         abs_all <= 0.
     );
 
@@ -95,8 +95,8 @@ fn test_media_buffering() {
     // should contain output
     let output = context.start_rendering();
     assert_float_eq!(
-        output.channel_data(0).as_slice(),
-        &[3.; BUFFER_SIZE][..],
+        output.get_channel_data(0),
+        &[3.; RENDER_QUANTUM_SIZE][..],
         abs_all <= 0.
     );
 
@@ -107,28 +107,28 @@ fn test_media_buffering() {
     // should contain previous output (looping)
     let output = context.start_rendering();
     assert_float_eq!(
-        output.channel_data(0).as_slice(),
-        &[2.; BUFFER_SIZE][..],
+        output.get_channel_data(0),
+        &[2.; RENDER_QUANTUM_SIZE][..],
         abs_all <= 0.
     );
     let output = context.start_rendering();
     assert_float_eq!(
-        output.channel_data(0).as_slice(),
-        &[3.; BUFFER_SIZE][..],
+        output.get_channel_data(0),
+        &[3.; RENDER_QUANTUM_SIZE][..],
         abs_all <= 0.
     );
     let output = context.start_rendering();
     assert_float_eq!(
-        output.channel_data(0).as_slice(),
-        &[2.; BUFFER_SIZE][..],
+        output.get_channel_data(0),
+        &[2.; RENDER_QUANTUM_SIZE][..],
         abs_all <= 0.
     );
 }
 
 #[test]
 fn test_media_seeking() {
-    const SAMPLE_RATE: SampleRate = SampleRate(BUFFER_SIZE as u32); // 1 render quantum = 1 second
-    let mut context = OfflineAudioContext::new(1, BUFFER_SIZE, SAMPLE_RATE);
+    const SAMPLE_RATE: SampleRate = SampleRate(RENDER_QUANTUM_SIZE as u32); // 1 render quantum = 1 second
+    let mut context = OfflineAudioContext::new(1, RENDER_QUANTUM_SIZE, SAMPLE_RATE);
 
     let block = Arc::new(AtomicBool::new(true));
 
@@ -150,8 +150,8 @@ fn test_media_seeking() {
     // should be silent since the media stream did not yield any output
     let output = context.start_rendering();
     assert_float_eq!(
-        output.channel_data(0).as_slice(),
-        &[0.; BUFFER_SIZE][..],
+        output.get_channel_data(0),
+        &[0.; RENDER_QUANTUM_SIZE][..],
         abs_all <= 0.
     );
 
@@ -165,8 +165,8 @@ fn test_media_seeking() {
     // should contain output, with first 2 values skipped
     let output = context.start_rendering();
     assert_float_eq!(
-        output.channel_data(0).as_slice(),
-        &[4.; BUFFER_SIZE][..],
+        output.get_channel_data(0),
+        &[4.; RENDER_QUANTUM_SIZE][..],
         abs_all <= 0.
     );
 }
